searchData={"items":[{"type":"module","title":"Ymlr","doc":"Encodes data into YAML documents using the `Ymlr.Encoder` protocol.\nEvery document starts with a separator (\"---\") and can be enhanced with comments.","ref":"Ymlr.html"},{"type":"function","title":"Ymlr.document/2","doc":"Encodes a given data as YAML document with a separator (\"---\") at the beginning.\n\nOptinally you can pass a tuple with comment(s) and data as first argument.","ref":"Ymlr.html#document/2"},{"type":"function","title":"Options - Ymlr.document/2","doc":"* `atoms` - when set to `true`, encodes atom map keys with a leading colon.\n* `sort_maps` - when set to `true`, sorts map by key-values.","ref":"Ymlr.html#document/2-options"},{"type":"function","title":"Examples - Ymlr.document/2","doc":"iex> Ymlr.document(%{a: 1})\n    {:ok, \"---\\na: 1\\n\"}\n\n    iex> Ymlr.document(%{a: 1}, atoms: true)\n    {:ok, \"---\\n:a: 1\\n\"}\n\n    iex> Ymlr.document({\"comment\", %{a: 1}})\n    {:ok, \"---\\n# comment\\na: 1\\n\"}\n\n    iex> Ymlr.document({[\"comment 1\", \"comment 2\"], %{a: 1}})\n    {:ok, \"---\\n# comment 1\\n# comment 2\\na: 1\\n\"}\n\n    iex> Ymlr.document(Map.new(1..33, &{&1, &1}), sort_maps: true)\n    {:ok, \"---\\n1: 1\\n2: 2\\n3: 3\\n4: 4\\n5: 5\\n6: 6\\n7: 7\\n8: 8\\n9: 9\\n10: 10\\n11: 11\\n12: 12\\n13: 13\\n14: 14\\n15: 15\\n16: 16\\n17: 17\\n18: 18\\n19: 19\\n20: 20\\n21: 21\\n22: 22\\n23: 23\\n24: 24\\n25: 25\\n26: 26\\n27: 27\\n28: 28\\n29: 29\\n30: 30\\n31: 31\\n32: 32\\n33: 33\\n\"}","ref":"Ymlr.html#document/2-examples"},{"type":"function","title":"Ymlr.document!/2","doc":"Encodes a given data as YAML document with a separator (\"---\") at the beginning. Raises if it cannot be encoded.\n\nOptinally you can pass a tuple with comment(s) and data as first argument.","ref":"Ymlr.html#document!/2"},{"type":"function","title":"Options - Ymlr.document!/2","doc":"* `atoms` - when set to `true`, encodes atom map keys with a leading colon.\n* `sort_maps` - when set to `true`, sorts map by key-values.","ref":"Ymlr.html#document!/2-options"},{"type":"function","title":"Examples - Ymlr.document!/2","doc":"iex> Ymlr.document!(%{a: 1})\n    \"---\\na: 1\\n\"\n\n    iex> Ymlr.document!(%{a: 1}, atoms: true)\n    \"---\\n:a: 1\\n\"\n\n    iex> Ymlr.document!({\"comment\", %{a: 1}})\n    \"---\\n# comment\\na: 1\\n\"\n\n    iex> Ymlr.document!({[\"comment 1\", \"comment 2\"], %{a: 1}})\n    \"---\\n# comment 1\\n# comment 2\\na: 1\\n\"\n\n    iex> Ymlr.document!(Map.new(1..33, &{&1, &1}), sort_maps: true)\n    \"---\\n1: 1\\n2: 2\\n3: 3\\n4: 4\\n5: 5\\n6: 6\\n7: 7\\n8: 8\\n9: 9\\n10: 10\\n11: 11\\n12: 12\\n13: 13\\n14: 14\\n15: 15\\n16: 16\\n17: 17\\n18: 18\\n19: 19\\n20: 20\\n21: 21\\n22: 22\\n23: 23\\n24: 24\\n25: 25\\n26: 26\\n27: 27\\n28: 28\\n29: 29\\n30: 30\\n31: 31\\n32: 32\\n33: 33\\n\"","ref":"Ymlr.html#document!/2-examples"},{"type":"function","title":"Ymlr.documents/2","doc":"Encodes a given list of data as \"---\" separated YAML documents.","ref":"Ymlr.html#documents/2"},{"type":"function","title":"Options - Ymlr.documents/2","doc":"* `atoms` - when set to `true`, encodes atom map keys with a leading colon.\n* `sort_maps` - when set to `true`, sorts map by key-values.","ref":"Ymlr.html#documents/2-options"},{"type":"function","title":"Examples - Ymlr.documents/2","doc":"iex> Ymlr.documents([%{a: 1}])\n    {:ok, \"---\\na: 1\\n\"}\n\n    iex> Ymlr.documents([%{a: 1}], atoms: true)\n    {:ok, \"---\\n:a: 1\\n\"}\n\n    iex> Ymlr.documents([%{a: 1}, %{b: 2}])\n    {:ok, \"---\\na: 1\\n\\n---\\nb: 2\\n\"}\n\n    iex> Ymlr.documents(%{a: \"a\"})\n    {:error, \"The given argument is not a list of documents. Use document/1, document/2, document!/1 or document!/2 for a single document.\"}","ref":"Ymlr.html#documents/2-examples"},{"type":"function","title":"Ymlr.documents!/2","doc":"Encodes a given list of data as \"---\" separated YAML documents. Raises if it cannot be encoded.","ref":"Ymlr.html#documents!/2"},{"type":"function","title":"Options - Ymlr.documents!/2","doc":"* `atoms` - when set to `true`, encodes atom map keys with a leading colon.\n* `sort_maps` - when set to `true`, sorts map by key-values.","ref":"Ymlr.html#documents!/2-options"},{"type":"function","title":"Examples - Ymlr.documents!/2","doc":"iex> Ymlr.documents!([%{a: 1}])\n    \"---\\na: 1\\n\"\n\n    iex> Ymlr.documents!([%{a: 1}], atoms: true)\n    \"---\\n:a: 1\\n\"\n\n    iex> Ymlr.documents!([%{a: 1}, %{b: 2}])\n    \"---\\na: 1\\n\\n---\\nb: 2\\n\"\n\n    iex> Ymlr.documents!(%{a: \"a\"})\n    ** (ArgumentError) The given argument is not a list of documents. Use document/1, document/2, document!/1 or document!/2 for a single document.","ref":"Ymlr.html#documents!/2-examples"},{"type":"type","title":"Ymlr.document/0","doc":"","ref":"Ymlr.html#t:document/0"},{"type":"protocol","title":"Ymlr.Encoder","doc":"Protocol controlling how a value is encoded to YAML.","ref":"Ymlr.Encoder.html"},{"type":"protocol","title":"Deriving - Ymlr.Encoder","doc":"The protocol allows leveraging the Elixir's `@derive` feature to simplify\nprotocol implementation in trivial cases. Accepted options are:\n\n  * `:only` - encodes only values of specified keys.\n  * `:except` - If set to a list of fields, all struct fields except specified\n    keys are encoded. If set to `:defaults`, all fields are encoded, except\n    the ones equaling their default value as defined in the struct.\n\nBy default all keys except the `:__struct__` key are encoded.","ref":"Ymlr.Encoder.html#module-deriving"},{"type":"protocol","title":"Example - Ymlr.Encoder","doc":"Let's assume a presence of the following struct:\n\n```\ndefmodule Test do\n  defstruct [:foo, :bar, :baz]\nend\n```\n\nIf we were to call `@derive Ymlr.Encoder` just before `defstruct`, an\nimplementation similar to the following implementation would be generated:\n\n```\ndefimpl Ymlr.Encoder, for: Test do\n  def encode(data, idnent_level) do\n    data\n    |> Map.take(unquote([:foo, :bar, :baz]))\n    |> Ymlr.Encode.map(idnent_level)\n  end\nend\n```\n\n#","ref":"Ymlr.Encoder.html#module-example"},{"type":"protocol","title":"Limit fields using the `only` Option - Ymlr.Encoder","doc":"We can limit the fields being encoded using the `:only` option:\n\n```\ndefmodule Test do\n  @derive {Ymlr.Encoder, only: [:foo]}\n  defstruct [:foo, :bar, :baz]\nend\n```\n\nThis would generate an implementation similar to the following:\n\n```\ndefimpl Ymlr.Encoder, for: Test do\n  def encode(data, idnent_level) do\n    data\n    |> Map.take(unquote([:foo]))\n    |> Ymlr.Encode.map(idnent_level)\n  end\nend\n```\n\n#","ref":"Ymlr.Encoder.html#module-limit-fields-using-the-only-option"},{"type":"protocol","title":"Exclude fields using the `except` Option - Ymlr.Encoder","doc":"We can exclude the fields being encoded using the `:except` option:\n\n```\ndefmodule Test do\n  @derive {Ymlr.Encoder, except: [:foo]}\n  defstruct [:foo, :bar, :baz]\nend\n```\n\nThis would generate an implementation similar to the following:\n\n```\ndefimpl Ymlr.Encoder, for: Test do\n  def encode(data, idnent_level) do\n    data\n    |> Map.take(unquote([:bar, :baz]))\n    |> Ymlr.Encode.map(idnent_level)\n  end\nend\n```\n\nWe can exclude the fields being left at their defaults by passing `except:\n:defaults`:\n\n```\ndefmodule TestExceptDefaults do\n  @derive {Ymlr.Encoder, except: :defaults}\n  defstruct [:foo, bar: 1, baz: :ok]\nend\n```\n\nThis would generate an implementation similar to the following:\n\n```\niex> Ymlr.document!(%TestExceptDefaults{foo: 1, bar: 1, baz: :error})\n\"baz: error\\nfoo: 1\"\n```","ref":"Ymlr.Encoder.html#module-exclude-fields-using-the-except-option"},{"type":"function","title":"Ymlr.Encoder.encode/3","doc":"Encodes the given data to YAML.","ref":"Ymlr.Encoder.html#encode/3"},{"type":"type","title":"Ymlr.Encoder.opts/0","doc":"","ref":"Ymlr.Encoder.html#t:opts/0"},{"type":"type","title":"Ymlr.Encoder.t/0","doc":"All the types that implement this protocol.","ref":"Ymlr.Encoder.html#t:t/0"},{"type":"extras","title":"ymlr - A YAML Encoder for Elixir","doc":"# ymlr - A YAML Encoder for Elixir\n\nymlr - A YAML encoder for Elixir.\n\n[![Module Version](https://img.shields.io/hexpm/v/ymlr.svg)](https://hex.pm/packages/ymlr)\n[![Coverage Status](https://coveralls.io/repos/github/ufirstgroup/ymlr/badge.svg?branch=main)](https://coveralls.io/github/ufirstgroup/ymlr?branch=main)\n[![Last Updated](https://img.shields.io/github/last-commit/ufirstgroup/ymlr.svg)](https://github.com/ufirstgroup/ymlr/commits/main)\n\n[![Build Status Code Qualits](https://github.com/ufirstgroup/ymlr/actions/workflows/code_quality.yaml/badge.svg)](https://github.com/ufirstgroup/ymlr/actions/workflows/code_quality.yaml)\n[![Build Status Elixir](https://github.com/ufirstgroup/ymlr/actions/workflows/elixir_matrix.yaml/badge.svg)](https://github.com/ufirstgroup/ymlr/actions/workflows/elixir_matrix.yaml)\n\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ymlr/)\n[![Total Download](https://img.shields.io/hexpm/dt/ymlr.svg)](https://hex.pm/packages/ymlr)\n[![License](https://img.shields.io/hexpm/l/ymlr.svg)](https://github.com/ufirstgroup/ymlr/blob/main/LICENSE)","ref":"readme.html"},{"type":"extras","title":"Installation - ymlr - A YAML Encoder for Elixir","doc":"The package can be installed by adding `ymlr` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ymlr, \"~> 4.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Examples - ymlr - A YAML Encoder for Elixir","doc":"See The usage livebook `usage.livemd` for more detailed examples.\n\n#","ref":"readme.html#examples"},{"type":"extras","title":"Encode a single document - optionally with comments: - ymlr - A YAML Encoder for Elixir","doc":"```elixir\n  iex> Ymlr.document!(%{a: 1})\n  \"\"\"\n  ---\n  a: 1\n  \"\"\"\n\n  iex> Ymlr.document!({\"comment\", %{a: 1}})\n  \"\"\"\n  ---\n  # comment\n  a: 1\n  \"\"\"\n\n  iex> Ymlr.document!({[\"comment 1\", \"comment 2\"], %{\"a\" => \"a\", \"b\" => :b, \"c\" => \"true\", \"d\" => \"100\"}})\n  \"\"\"\n  ---\n  # comment 1\n  # comment 2\n  a: a\n  b: b\n  c: 'true'\n  d: '100'\n  \"\"\"\n```\n\n#","ref":"readme.html#encode-a-single-document-optionally-with-comments"},{"type":"extras","title":"Encode a multiple documents - ymlr - A YAML Encoder for Elixir","doc":"```elixir\niex> Ymlr.documents!([%{a: 1}, %{b: 2}])\n\"\"\"\n---\na: 1\n\n---\nb: 2\n\"\"\"\n```","ref":"readme.html#encode-a-multiple-documents"},{"type":"extras","title":"Support for atoms - ymlr - A YAML Encoder for Elixir","doc":"By default, atoms as map keys are encoded as strings (without the leading\ncolon). If you want atoms to be encoded with a leading colon in order to be able\nto parse it later using [`YamlElixir`'s `atoms`\noption](https://hexdocs.pm/yaml_elixir/readme.html#support-for-atoms), you can\npass `atoms: true` as second argument to any of the `Ymlr` module's functions:\n\n\n```elixir\niex> Ymlr.document!(%{a: 1}, atoms: true)\n\"\"\"\n---\n:a: 1\n\"\"\"\n```\n\n#","ref":"readme.html#support-for-atoms"},{"type":"extras","title":"Encode maps with keys sorted - ymlr - A YAML Encoder for Elixir","doc":"Maps in elixir, implemented by erlang `:maps`, internally are `flatmap`s or `hashmap`s by size.\nLarge maps will be encoded in strange order.\n\n```elixir\niex> 1..33 |> Map.new(&{&1, &1})|> Ymlr.document!() |> IO.puts\n---\n4: 4\n25: 25\n8: 8\n...\n\n```\n\nBy using `:sort_maps` option, ymlr will encode all entries sorted.\n\n```elixir\niex> 1..33 |> Map.new(&{&1, &1})|> Ymlr.document!(sort_maps: true) |> IO.puts\n---\n1: 1\n2: 2\n3: 3\n...\n\n```","ref":"readme.html#encode-maps-with-keys-sorted"},{"type":"extras","title":"usage","doc":"# Usage\n\n```elixir\nMix.install([:kino, :ymlr, :yaml_elixir])\n\nfull = %{\n  \"atom\" => :ymlr,\n  \"date\" => ~D[2018-11-15],\n  \"date_time\" => ~U[2018-11-15 11:00:00Z],\n  \"list\" => [\"item 1\", \"item 2\", \"item 3\"],\n  \"nested list\" => [[\"item 1.1\", \"item 1.2\"], [\"item 2.1\", \"item 2.2\", \"item 2.3\"]],\n  \"nested map\" => %{\n    \"some\" => %{\n      \"nested\" => [\"data\"]\n    }\n  },\n  \"numbers\" => %{\n    \"float\" => 3.14159265,\n    \"hex\" => 0x0B1010,\n    \"int\" => 123,\n    \"oct\" => 0o777\n  },\n  \"numbers as strings\" => %{\n    \"float\" => \"3.14159265\",\n    \"hex\" => \"0x0b1010\",\n    \"int\" => \"123\",\n    \"oct\" => \"0o777\"\n  },\n  \"string\" => \"hello world\",\n  \"string (multiline)\" => \"hello\\nworld\"\n}\n\nsimple_1 = %{\"message\" => \"hello world\"}\nsimple_2 = %{message: \"nice to be here\"}\n:ok\n```\n\n \n\n```\nResolving Hex dependencies...\nDependency resolution completed:\nNew:\n  kino 0.9.2\n  table 0.1.2\n  yamerl 0.10.0\n  yaml_elixir 2.9.0\n  ymlr 3.0.1\n* Getting kino (Hex package)\n* Getting ymlr (Hex package)\n* Getting yaml_elixir (Hex package)\n* Getting yamerl (Hex package)\n* Getting table (Hex package)\n==> table\nCompiling 5 files (.ex)\nGenerated table app\n==> ymlr\nCompiling 2 files (.ex)\nGenerated ymlr app\n==> kino\nCompiling 39 files (.ex)\nGenerated kino app\n===> Analyzing applications...\n===> Compiling yamerl\n==> yaml_elixir\nCompiling 6 files (.ex)\nGenerated yaml_elixir app\n```\n\n \n\n```\n:ok\n```","ref":"usage.html"},{"type":"extras","title":"Encoding a single document - usage","doc":"[![Run in Livebook](https://livebook.dev/badge/v1/pink.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fufirstgroup%2Fymlr%2Fblob%2Fmain%2Fusage.livemd)\n\nNote: We defined document data as variables `full`, `simple_1` and `simple_2` in the setup block at the top of this livebook.\n\n \n\n```elixir\nfull\n|> Ymlr.document!()\n|> IO.puts()\n```\n\n \n\n```\n---\natom: ymlr\ndate:\n  2018-11-15\ndate_time:\n  2018-11-15T11:00:00Z\nlist:\n  - item 1\n  - item 2\n  - item 3\nnested list:\n  - - item 1.1\n    - item 1.2\n  - - item 2.1\n    - item 2.2\n    - item 2.3\nnested map:\n  some:\n    nested:\n      - data\nnumbers:\n  float: 3.14159265\n  hex: 725008\n  int: 123\n  oct: 511\nnumbers as strings:\n  float: '3.14159265'\n  hex: '0x0b1010'\n  int: '123'\n  oct: '0o777'\nstring: hello world\nstring (multiline): |-\n  hello\n  world\n\n```\n\n \n\n```\n:ok\n```\n\n \n\n```elixir\nsimple_1\n|> Ymlr.document()\n```\n\n \n\n```\n{:ok, \"---\\nmessage: hello world\\n\"}\n```","ref":"usage.html#encoding-a-single-document"},{"type":"extras","title":"Encoding multiple documents - usage","doc":"```elixir\n[simple_1, simple_2]\n|> Ymlr.documents!()\n|> IO.puts()\n```\n\n \n\n```\n---\nmessage: hello world\n\n---\nmessage: nice to be here\n\n```\n\n \n\n```\n:ok\n```\n\n \n\n```elixir\n[simple_1, simple_2]\n|> Ymlr.documents()\n```\n\n \n\n```\n{:ok, \"---\\nmessage: hello world\\n\\n---\\nmessage: nice to be here\\n\"}\n```","ref":"usage.html#encoding-multiple-documents"},{"type":"extras","title":"Adding comments - usage","doc":"To add a comment at the top of the YAML document, pass a tuple in the form `{comment, document}` to any of the functions.\n\n \n\n```elixir\n{\"Single comment\", simple_1}\n|> Ymlr.document!()\n|> IO.puts()\n```\n\n \n\n```\n---\n# Single comment\nmessage: hello world\n\n```\n\n \n\n```\n:ok\n```\n\nThe first element of the tuple can be a list of comments:\n\n \n\n```elixir\n{[\"First comment\", \"Second Comment\", \"Third Comment\"], simple_1}\n|> Ymlr.document!()\n|> IO.puts()\n```\n\n \n\n```\n---\n# First comment\n# Second Comment\n# Third Comment\nmessage: hello world\n\n```\n\n \n\n```\n:ok\n```\n\nMultiple documents with comments:\n\n```elixir\n[\n  {[\"First doc, first comment\", \"First doc, second Comment\", \"First doc,  Comment\"], simple_1},\n  {[\"Second doc, first comment\", \"Second doc, second comment\"], simple_2}\n]\n|> Ymlr.documents!()\n|> IO.puts()\n```\n\n \n\n```\n---\n# First doc, first comment\n# First doc, second Comment\n# First doc,  Comment\nmessage: hello world\n\n---\n# Second doc, first comment\n# Second doc, second comment\nmessage: nice to be here\n\n```\n\n \n\n```\n:ok\n```","ref":"usage.html#adding-comments"},{"type":"extras","title":"Encoding Atom Map Keys - usage","doc":"By default, atoms as map keys are encoded as strings (without the leading\ncolon). If you want atoms to be encoded with a leading colon in order to be able\nto parse it later using [`YamlElixir`'s `atoms`\noption](https://hexdocs.pm/yaml_elixir/readme.html#support-for-atoms), you can\npass `atoms: true` as second argument to any of the `Ymlr` module's functions:\n\n```elixir\nsimple_2\n|> Ymlr.document!(atoms: true)\n|> YamlElixir.read_from_string!(atoms: true)\n```\n\n \n\n```\n%{message: \"nice to be here\"}\n```","ref":"usage.html#encoding-atom-map-keys"},{"type":"extras","title":"Encode maps with keys sorted - usage","doc":"Maps in elixir, implemented by erlang `:maps`, internally are `flatmap`s or `hashmap`s by size.\nLarge maps will be encoded in strange order.\n\n```elixir\nmap = Map.new(1..33, &{&1, &1})\nmap |> Ymlr.document!() |> IO.puts()\n```\n\n \n\n```\n---\n4: 4\n25: 25\n8: 8\n...\n\n```\n\nBy using `:sort_maps` option, ymlr will encode all entries sorted.\n\n```elixir\nmap |> Ymlr.document!(sort_maps: true) |> IO.puts()\n```\n\n \n\n```\n---\n1: 1\n2: 2\n3: 3\n...\n\n```","ref":"usage.html#encode-maps-with-keys-sorted"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"<!-- #","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added | Changed | Deprecated | Removed | Fixed | Security --> - Changelog","doc":"## [4.2.0] - 2023-08-18\n\n#","ref":"changelog.html#added-changed-deprecated-removed-fixed-security"},{"type":"extras","title":"Added - Changelog","doc":"- Adds an option `sort_maps` to encode map with entries sorted - [#139](https://github.com/ufirstgroup/ymlr/issues/139),[#144](https://github.com/ufirstgroup/ymlr/pull/144)\n- Quote values beginning with `:{` - [#140](https://github.com/ufirstgroup/ymlr/issues/140),[#141](https://github.com/ufirstgroup/ymlr/pull/141)\n\n## [4.1.0] - 2023-04-23\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- `Ymlr.Encoder` - Option `except: :defaults` to exclude default values\n\n## [4.0.0] - 2023-04-16\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Breaking Change - Changelog","doc":"**Up to and including version 3.x, `ymlr` would encode structs out of the box.\nThis version introduces protocols so and structs need to `@derive Ymlr.Encoder`\nin order to be encoded. See the documentation of the `Ymlr.Encoder` protocol\nfor further information.**\n\n#","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Changed - Changelog","doc":"- A protocol based implementation was added which give more freedom to users of this library - [#118](https://github.com/ufirstgroup/ymlr/pull/118)\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Adds an option `atoms` to encode atom map keys with a leading colon.\n- Tuples are now encoded as lists.\n\n## [3.0.1] - 2022-09-05\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Wrap map keys in doouble quotes when required ([#94](https://github.com/ufirstgroup/ymlr/issues/94), [#95](https://github.com/ufirstgroup/ymlr/pull/95))\n- Encode structs by turning them to lists before mapping over them\n\n## [3.0.0] - 2022-08-07\n\n**In this release we changed the way `DateTime` is encoded (see below). This can be a breaking change if you rely on the old date format with spaces. Because of this change, version 3.0.0 is now again compatible with Elixir 1.10**\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- use `Enum.map_join/3` indead of `Enum.map/2` and `Enum.join/2` as it's more efficient according to credo recommendations\n- Change the serialization of timestamps to use the canonical (iso8601) format, i.e. before: `2022-07-31 14:48:48.000000000 Z` and now: `\"2022-07-31T14:48:48Z\"` ([#87](https://github.com/ufirstgroup/ymlr/issues/87), [#90](https://github.com/ufirstgroup/ymlr/pull/90))\n\n## [2.0.0] - 2021-04-02\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Changelog","doc":"- 2.0 and upwards don't support Elixir 1.10 anymore. Use version 1.x for Elixir 1.10 support.\n\n#","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- Date and DateTime support (#17)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Chores - Changelog","doc":"- yaml_elixir upgraded to 2.6.0\n- excoveralls upgraded to 0.14.0\n- ex_doc upgraded to 0.24.1\n- credo upgraded to 1.5.5\n- dialyxir upgraded to 1.1.0\n\n## [1.1.0] - 2021-04-02\n\n#","ref":"changelog.html#chores"},{"type":"extras","title":"Added - Changelog","doc":"- Date and DateTime support (#17)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Chores - Changelog","doc":"- yaml_elixir upgraded to 2.6.0\n- excoveralls upgraded to 0.14.0\n- ex_doc upgraded to 0.24.1\n- credo upgraded to 1.5.5\n- dialyxir upgraded to 1.1.0\n\n## [1.0.1] - 2020-09-22\n\n#","ref":"changelog.html#chores"},{"type":"extras","title":"Changed - Changelog","doc":"- Rescue ArgumentError exception for oversize floats according to Float.parse/1 doc\n\n## [1.0.0] - 2020-08-21\n\nNo changes in this release. We have tested the library on a big bunch of CRDs and feel confident to publish a sable relese.\n\n## [0.0.1] - 2020-07-31\n\nFirst ymlr beta release","ref":"changelog.html#changed"}],"content_type":"text/markdown"}