searchNodes=[{"doc":"Encodes data into YAML documents using the Ymlr.Encoder protocol. Every document starts with a separator (&quot;---&quot;) and can be enhanced with comments.","ref":"Ymlr.html","title":"Ymlr","type":"module"},{"doc":"Encodes a given data as YAML document with a separator (&quot;---&quot;) at the beginning. Optinally you can pass a tuple with comment(s) and data as first argument. Options atoms - when set to true , encodes atom map keys with a leading colon. Examples iex&gt; Ymlr . document ( %{ a : 1 } ) { :ok , &quot;--- \\n a: 1 \\n &quot; } iex&gt; Ymlr . document ( %{ a : 1 } , atoms : true ) { :ok , &quot;--- \\n :a: 1 \\n &quot; } iex&gt; Ymlr . document ( { &quot;comment&quot; , %{ a : 1 } } ) { :ok , &quot;--- \\n # comment \\n a: 1 \\n &quot; } iex&gt; Ymlr . document ( { [ &quot;comment 1&quot; , &quot;comment 2&quot; ] , %{ a : 1 } } ) { :ok , &quot;--- \\n # comment 1 \\n # comment 2 \\n a: 1 \\n &quot; }","ref":"Ymlr.html#document/2","title":"Ymlr.document/2","type":"function"},{"doc":"Encodes a given data as YAML document with a separator (&quot;---&quot;) at the beginning. Raises if it cannot be encoded. Optinally you can pass a tuple with comment(s) and data as first argument. Options atoms - when set to true , encodes atom map keys with a leading colon. Examples iex&gt; Ymlr . document! ( %{ a : 1 } ) &quot;--- \\n a: 1 \\n &quot; iex&gt; Ymlr . document! ( %{ a : 1 } , atoms : true ) &quot;--- \\n :a: 1 \\n &quot; iex&gt; Ymlr . document! ( { &quot;comment&quot; , %{ a : 1 } } ) &quot;--- \\n # comment \\n a: 1 \\n &quot; iex&gt; Ymlr . document! ( { [ &quot;comment 1&quot; , &quot;comment 2&quot; ] , %{ a : 1 } } ) &quot;--- \\n # comment 1 \\n # comment 2 \\n a: 1 \\n &quot;","ref":"Ymlr.html#document!/2","title":"Ymlr.document!/2","type":"function"},{"doc":"Encodes a given list of data as &quot;---&quot; separated YAML documents. Options atoms - when set to true , encodes atom map keys with a leading colon. Examples iex&gt; Ymlr . documents ( [ %{ a : 1 } ] ) { :ok , &quot;--- \\n a: 1 \\n &quot; } iex&gt; Ymlr . documents ( [ %{ a : 1 } ] , atoms : true ) { :ok , &quot;--- \\n :a: 1 \\n &quot; } iex&gt; Ymlr . documents ( [ %{ a : 1 } , %{ b : 2 } ] ) { :ok , &quot;--- \\n a: 1 \\n \\n --- \\n b: 2 \\n &quot; } iex&gt; Ymlr . documents ( %{ a : &quot;a&quot; } ) { :error , &quot;The given argument is not a list of documents. Use document/1, document/2, document!/1 or document!/2 for a single document.&quot; }","ref":"Ymlr.html#documents/2","title":"Ymlr.documents/2","type":"function"},{"doc":"Encodes a given list of data as &quot;---&quot; separated YAML documents. Raises if it cannot be encoded. Options atoms - when set to true , encodes atom map keys with a leading colon. Examples iex&gt; Ymlr . documents! ( [ %{ a : 1 } ] ) &quot;--- \\n a: 1 \\n &quot; iex&gt; Ymlr . documents! ( [ %{ a : 1 } ] , atoms : true ) &quot;--- \\n :a: 1 \\n &quot; iex&gt; Ymlr . documents! ( [ %{ a : 1 } , %{ b : 2 } ] ) &quot;--- \\n a: 1 \\n \\n --- \\n b: 2 \\n &quot; iex&gt; Ymlr . documents! ( %{ a : &quot;a&quot; } ) ** (ArgumentError) The given argument is not a list of documents. Use document/1, document/2, document!/1 or document!/2 for a single document.","ref":"Ymlr.html#documents!/2","title":"Ymlr.documents!/2","type":"function"},{"doc":"","ref":"Ymlr.html#t:document/0","title":"Ymlr.document/0","type":"type"},{"doc":"Protocol controlling how a value is encoded to YAML. Deriving The protocol allows leveraging the Elixir's @derive feature to simplify protocol implementation in trivial cases. Accepted options are: :only - encodes only values of specified keys. :except - If set to a list of fields, all struct fields except specified keys are encoded. If set to :defaults , all fields are encoded, except the ones equaling their default value as defined in the struct. By default all keys except the :__struct__ key are encoded. Example Let's assume a presence of the following struct: defmodule Test do defstruct [ :foo , :bar , :baz ] end If we were to call @derive Ymlr.Encoder just before defstruct , an implementation similar to the following implementation would be generated: defimpl Ymlr.Encoder , for : Test do def encode ( data , idnent_level ) do data |&gt; Map . take ( unquote ( [ :foo , :bar , :baz ] ) ) |&gt; Ymlr.Encode . map ( idnent_level ) end end Limit fields using the only Option We can limit the fields being encoded using the :only option: defmodule Test do @derive { Ymlr.Encoder , only : [ :foo ] } defstruct [ :foo , :bar , :baz ] end This would generate an implementation similar to the following: defimpl Ymlr.Encoder , for : Test do def encode ( data , idnent_level ) do data |&gt; Map . take ( unquote ( [ :foo ] ) ) |&gt; Ymlr.Encode . map ( idnent_level ) end end Exclude fields using the except Option We can exclude the fields being encoded using the :except option: defmodule Test do @derive { Ymlr.Encoder , except : [ :foo ] } defstruct [ :foo , :bar , :baz ] end This would generate an implementation similar to the following: defimpl Ymlr.Encoder , for : Test do def encode ( data , idnent_level ) do data |&gt; Map . take ( unquote ( [ :bar , :baz ] ) ) |&gt; Ymlr.Encode . map ( idnent_level ) end end We can exclude the fields being left at their defaults by passing except: :defaults : defmodule TestExceptDefaults do @derive { Ymlr.Encoder , except : :defaults } defstruct [ :foo , bar : 1 , baz : :ok ] end This would generate an implementation similar to the following: iex&gt; Ymlr . document! ( % TestExceptDefaults { foo : 1 , bar : 1 , baz : :error } ) &quot;baz: error \\n foo: 1&quot;","ref":"Ymlr.Encoder.html","title":"Ymlr.Encoder","type":"protocol"},{"doc":"Encodes the given data to YAML.","ref":"Ymlr.Encoder.html#encode/3","title":"Ymlr.Encoder.encode/3","type":"function"},{"doc":"","ref":"Ymlr.Encoder.html#t:opts/0","title":"Ymlr.Encoder.opts/0","type":"type"},{"doc":"","ref":"Ymlr.Encoder.html#t:t/0","title":"Ymlr.Encoder.t/0","type":"type"},{"doc":"ymlr - A YAML encoder for Elixir.","ref":"readme.html","title":"ymlr - A YAML Encoder for Elixir","type":"extras"},{"doc":"The package can be installed by adding ymlr to your list of dependencies in mix.exs : def deps do [ { :ymlr , &quot;~&gt; 4.0&quot; } ] end","ref":"readme.html#installation","title":"ymlr - A YAML Encoder for Elixir - Installation","type":"extras"},{"doc":"See The usage livebook usage.livemd for more detailed examples. Encode a single document - optionally with comments: iex&gt; Ymlr . document! ( %{ a : 1 } ) &quot;&quot;&quot; --- a: 1 &quot;&quot;&quot; iex&gt; Ymlr . document! ( { &quot;comment&quot; , %{ a : 1 } } ) &quot;&quot;&quot; --- # comment a: 1 &quot;&quot;&quot; iex&gt; Ymlr . document! ( { [ &quot;comment 1&quot; , &quot;comment 2&quot; ] , %{ &quot;a&quot; =&gt; &quot;a&quot; , &quot;b&quot; =&gt; :b , &quot;c&quot; =&gt; &quot;true&quot; , &quot;d&quot; =&gt; &quot;100&quot; } } ) &quot;&quot;&quot; --- # comment 1 # comment 2 a: a b: b c: &#39;true&#39; d: &#39;100&#39; &quot;&quot;&quot; Encode a multiple documents iex&gt; Ymlr . documents! ( [ %{ a : 1 } , %{ b : 2 } ] ) &quot;&quot;&quot; --- a: 1 --- b: 2 &quot;&quot;&quot;","ref":"readme.html#examples","title":"ymlr - A YAML Encoder for Elixir - Examples","type":"extras"},{"doc":"By default, atoms as map keys are encoded as strings (without the leading colon). If you want atoms to be encoded with a leading colon in order to be able to parse it later using YamlElixir 's atoms option , you can pass atoms: true as second argument to any of the Ymlr module's functions: iex&gt; Ymlr . document! ( %{ a : 1 } , atoms : true ) &quot;&quot;&quot; --- :a: 1 &quot;&quot;&quot;","ref":"readme.html#support-for-atoms","title":"ymlr - A YAML Encoder for Elixir - Support for atoms","type":"extras"},{"doc":"Mix . install ( [ :kino , :ymlr , :yaml_elixir ] ) full = %{ &quot;atom&quot; =&gt; :ymlr , &quot;date&quot; =&gt; ~D[2018-11-15] , &quot;date_time&quot; =&gt; ~U[2018-11-15 11:00:00Z] , &quot;list&quot; =&gt; [ &quot;item 1&quot; , &quot;item 2&quot; , &quot;item 3&quot; ] , &quot;nested list&quot; =&gt; [ [ &quot;item 1.1&quot; , &quot;item 1.2&quot; ] , [ &quot;item 2.1&quot; , &quot;item 2.2&quot; , &quot;item 2.3&quot; ] ] , &quot;nested map&quot; =&gt; %{ &quot;some&quot; =&gt; %{ &quot;nested&quot; =&gt; [ &quot;data&quot; ] } } , &quot;numbers&quot; =&gt; %{ &quot;float&quot; =&gt; 3.14159265 , &quot;hex&quot; =&gt; 0x0B1010 , &quot;int&quot; =&gt; 123 , &quot;oct&quot; =&gt; 0o777 } , &quot;numbers as strings&quot; =&gt; %{ &quot;float&quot; =&gt; &quot;3.14159265&quot; , &quot;hex&quot; =&gt; &quot;0x0b1010&quot; , &quot;int&quot; =&gt; &quot;123&quot; , &quot;oct&quot; =&gt; &quot;0o777&quot; } , &quot;string&quot; =&gt; &quot;hello world&quot; , &quot;string (multiline)&quot; =&gt; &quot;hello \\n world&quot; } simple_1 = %{ &quot;message&quot; =&gt; &quot;hello world&quot; } simple_2 = %{ message : &quot;nice to be here&quot; } :ok Resolving Hex dependencies ... Dependency resolution completed : New : kino 0.9 . 2 table 0.1 . 2 yamerl 0.10 . 0 yaml_elixir 2.9 . 0 ymlr 3.0 . 1 * Getting kino ( Hex package ) * Getting ymlr ( Hex package ) * Getting yaml_elixir ( Hex package ) * Getting yamerl ( Hex package ) * Getting table ( Hex package ) == &gt; table Compiling 5 files ( . ex ) Generated table app == &gt; ymlr Compiling 2 files ( . ex ) Generated ymlr app == &gt; kino Compiling 39 files ( . ex ) Generated kino app === &gt; Analyzing applications ... === &gt; Compiling yamerl == &gt; yaml_elixir Compiling 6 files ( . ex ) Generated yaml_elixir app :ok","ref":"usage.html","title":"Usage","type":"extras"},{"doc":"Note: We defined document data as variables full , simple_1 and simple_2 in the setup block at the top of this livebook. full |&gt; Ymlr . document! ( ) |&gt; IO . puts ( ) -- - atom : ymlr date : 2018 - 11 - 15 date_time : 2018 - 11 - 15 T11 : 00 : 00 Z list : - item 1 - item 2 - item 3 nested list : - - item 1.1 - item 1.2 - - item 2.1 - item 2.2 - item 2.3 nested map : some : nested : - data numbers : float : 3.14159265 hex : 725008 int : 123 oct : 511 numbers as strings : float : &#39;3.14159265&#39; hex : &#39;0x0b1010&#39; int : &#39;123&#39; oct : &#39;0o777&#39; string : hello world string ( multiline ) : | - hello world :ok simple_1 |&gt; Ymlr . document ( ) { :ok , &quot;--- \\n message: hello world \\n &quot; }","ref":"usage.html#encoding-a-single-document","title":"Usage - Encoding a single document","type":"extras"},{"doc":"[ simple_1 , simple_2 ] |&gt; Ymlr . documents! ( ) |&gt; IO . puts ( ) -- - message : hello world -- - message : nice to be here :ok [ simple_1 , simple_2 ] |&gt; Ymlr . documents ( ) { :ok , &quot;--- \\n message: hello world \\n \\n --- \\n message: nice to be here \\n &quot; }","ref":"usage.html#encoding-multiple-documents","title":"Usage - Encoding multiple documents","type":"extras"},{"doc":"To add a comment at the top of the YAML document, pass a tuple in the form {comment, document} to any of the functions. { &quot;Single comment&quot; , simple_1 } |&gt; Ymlr . document! ( ) |&gt; IO . puts ( ) -- - # Single comment message : hello world :ok The first element of the tuple can be a list of comments: { [ &quot;First comment&quot; , &quot;Second Comment&quot; , &quot;Third Comment&quot; ] , simple_1 } |&gt; Ymlr . document! ( ) |&gt; IO . puts ( ) -- - # First comment # Second Comment # Third Comment message : hello world :ok Multiple documents with comments: [ { [ &quot;First doc, first comment&quot; , &quot;First doc, second Comment&quot; , &quot;First doc, Comment&quot; ] , simple_1 } , { [ &quot;Second doc, first comment&quot; , &quot;Second doc, second comment&quot; ] , simple_2 } ] |&gt; Ymlr . documents! ( ) |&gt; IO . puts ( ) -- - # First doc, first comment # First doc, second Comment # First doc, Comment message : hello world -- - # Second doc, first comment # Second doc, second comment message : nice to be here :ok","ref":"usage.html#adding-comments","title":"Usage - Adding comments","type":"extras"},{"doc":"By default, atoms as map keys are encoded as strings (without the leading colon). If you want atoms to be encoded with a leading colon in order to be able to parse it later using YamlElixir 's atoms option , you can pass atoms: true as second argument to any of the Ymlr module's functions: simple_2 |&gt; Ymlr . document! ( atoms : true ) |&gt; YamlElixir . read_from_string! ( atoms : true ) %{ message : &quot;nice to be here&quot; }","ref":"usage.html#encoding-atom-map-keys","title":"Usage - Encoding Atom Map Keys","type":"extras"},{"doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"","ref":"changelog.html#unreleased","title":"Changelog - Unreleased","type":"extras"},{"doc":"Added Ymlr.Encoder - Option except: :defaults to exclude default values","ref":"changelog.html#4-1-0-2023-04-23","title":"Changelog - [4.1.0] - 2023-04-23","type":"extras"},{"doc":"Breaking Change Up to and including version 3.x, ymlr would encode structs out of the box. This version introduces protocols so and structs need to @derive Ymlr.Encoder in order to be encoded. See the documentation of the Ymlr.Encoder protocol for further information. Changed A protocol based implementation was added which give more freedom to users of this library - #118 Added Adds an option atoms to encode atom map keys with a leading colon. Tuples are now encoded as lists.","ref":"changelog.html#4-0-0-2023-04-16","title":"Changelog - [4.0.0] - 2023-04-16","type":"extras"},{"doc":"Fixed Wrap map keys in doouble quotes when required ( #94 , #95 ) Encode structs by turning them to lists before mapping over them","ref":"changelog.html#3-0-1-2022-09-05","title":"Changelog - [3.0.1] - 2022-09-05","type":"extras"},{"doc":"In this release we changed the way DateTime is encoded (see below). This can be a breaking change if you rely on the old date format with spaces. Because of this change, version 3.0.0 is now again compatible with Elixir 1.10 Changed use Enum.map_join/3 indead of Enum.map/2 and Enum.join/2 as it's more efficient according to credo recommendations Change the serialization of timestamps to use the canonical (iso8601) format, i.e. before: 2022-07-31 14:48:48.000000000 Z and now: &quot;2022-07-31T14:48:48Z&quot; ( #87 , #90 )","ref":"changelog.html#3-0-0-2022-08-07","title":"Changelog - [3.0.0] - 2022-08-07","type":"extras"},{"doc":"Removed 2.0 and upwards don't support Elixir 1.10 anymore. Use version 1.x for Elixir 1.10 support. Added Date and DateTime support (#17) Chores yaml_elixir upgraded to 2.6.0 excoveralls upgraded to 0.14.0 ex_doc upgraded to 0.24.1 credo upgraded to 1.5.5 dialyxir upgraded to 1.1.0","ref":"changelog.html#2-0-0-2021-04-02","title":"Changelog - [2.0.0] - 2021-04-02","type":"extras"},{"doc":"Added Date and DateTime support (#17) Chores yaml_elixir upgraded to 2.6.0 excoveralls upgraded to 0.14.0 ex_doc upgraded to 0.24.1 credo upgraded to 1.5.5 dialyxir upgraded to 1.1.0","ref":"changelog.html#1-1-0-2021-04-02","title":"Changelog - [1.1.0] - 2021-04-02","type":"extras"},{"doc":"Changed Rescue ArgumentError exception for oversize floats according to Float.parse/1 doc","ref":"changelog.html#1-0-1-2020-09-22","title":"Changelog - [1.0.1] - 2020-09-22","type":"extras"},{"doc":"No changes in this release. We have tested the library on a big bunch of CRDs and feel confident to publish a sable relese.","ref":"changelog.html#1-0-0-2020-08-21","title":"Changelog - [1.0.0] - 2020-08-21","type":"extras"},{"doc":"First ymlr beta release","ref":"changelog.html#0-0-1-2020-07-31","title":"Changelog - [0.0.1] - 2020-07-31","type":"extras"}]